from distutils.core import *

setup(name='Txtr',
      version='1',
      author = 'Eslam Mostafa',
      author_email = 'cseslam@gmail.com',
      license = 'GPL3',
      description = 'A simple and neat text editor designed for gnu/linux',
      packages=['txtr',],
      scripts=['txtr/txtr',],
      )
